{
    "$graph": [
        {
            "class": "CommandLineTool",
            "description": "Run lobSTR allelotype classifier.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "description": "BAM file to analyze. Should have a unique read group and be sorted and indexed.\n",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#allelotype.cwl/bam"
                },
                {
                    "type": "File",
                    "description": "File to read noise model parameters from (.stepmodel)\n",
                    "inputBinding": {
                        "prefix": "--noise_model",
                        "valueFrom": "$( {\"path\": self.dirname + \"/\" + self.nameroot, \"class\": \"File\"})\n"
                    },
                    "secondaryFiles": [
                        "^.stuttermodel"
                    ],
                    "id": "#allelotype.cwl/noise_model"
                },
                {
                    "type": "string",
                    "description": "Prefix for output files. will output prefix.vcf and prefix.genotypes.tab",
                    "inputBinding": {
                        "prefix": "--out"
                    },
                    "id": "#allelotype.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "description": "lobSTR's bwa reference files",
                    "inputBinding": {
                        "prefix": "--index-prefix",
                        "valueFrom": "$({\"path\": self.path.replace(/ref\\.fasta$/, \"\"), \"class\": \"File\"})\n"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".rbwt",
                        ".rpac",
                        ".rsa",
                        "$(self.path.replace(/ref$/, \"chromsizes.tab\"))",
                        "$(self.path.replace(/ref$/, \"mergedref.bed\"))",
                        "$(self.path)_map.tab"
                    ],
                    "id": "#allelotype.cwl/reference"
                },
                {
                    "type": "File",
                    "description": "File containing statistics for each STR.\n",
                    "inputBinding": {
                        "prefix": "--strinfo"
                    },
                    "id": "#allelotype.cwl/strinfo"
                }
            ],
            "baseCommand": [
                "allelotype",
                "--command",
                "classify"
            ],
            "arguments": [
                "--noweb"
            ],
            "id": "#allelotype.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs['output_prefix'] + '.vcf')"
                    },
                    "id": "#allelotype.cwl/vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs['output_prefix'] + '.allelotype.stats')"
                    },
                    "id": "#allelotype.cwl/vcf_stats"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "lobSTR",
            "description": "lobSTR is a tool for profiling Short Tandem Repeats (STRs) from high throughput sequencing data.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--bampair"
                    },
                    "description": "Reads are in BAM format and are paired-end. NOTE: BAM file MUST be sorted or collated by read name.\n",
                    "id": "#lobSTR-tool.cwl/bampair"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--bwaq"
                    },
                    "description": "trim reads based on quality score. Same as the -q parameter in BWA",
                    "id": "#lobSTR-tool.cwl/bwaq"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-e"
                    },
                    "description": "Maximum number of gap extends allowed in each flanking region",
                    "id": "#lobSTR-tool.cwl/e"
                },
                {
                    "type": "float",
                    "default": 0.45,
                    "inputBinding": {
                        "prefix": "--entropy-threshold"
                    },
                    "description": "Threshold score to call a window periodic",
                    "id": "#lobSTR-tool.cwl/entropy-threshold"
                },
                {
                    "type": "int",
                    "default": 1000,
                    "inputBinding": {
                        "prefix": "--extend"
                    },
                    "description": "Number of bp the reference was extended when building the index. Must be same as --extend parameter used to run lobstr_index.py",
                    "id": "#lobSTR-tool.cwl/extend"
                },
                {
                    "type": "int",
                    "default": 16,
                    "inputBinding": {
                        "prefix": "--fft-window-size"
                    },
                    "description": "Size of sliding entropy window",
                    "id": "#lobSTR-tool.cwl/fft-window-size"
                },
                {
                    "type": "int",
                    "default": 4,
                    "inputBinding": {
                        "prefix": "--fft-window-step"
                    },
                    "description": "Step size of the sliding window",
                    "id": "#lobSTR-tool.cwl/fft-window-step"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "description": "List of files of single ends in fasta, fastq, or BAM files to align. Also use this parameter to specify paired-end BAM files to align.",
                    "inputBinding": {
                        "prefix": "--files",
                        "position": 2,
                        "itemSeparator": ","
                    },
                    "id": "#lobSTR-tool.cwl/files"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "description": "Maximum number of gap opens allowed in each flanking region",
                    "id": "#lobSTR-tool.cwl/g"
                },
                {
                    "type": "int",
                    "default": 100,
                    "inputBinding": {
                        "prefix": "--mapq"
                    },
                    "description": "maximum allowed mapq score calculated as the sum of qualities at base mismatches",
                    "id": "#lobSTR-tool.cwl/maq"
                },
                {
                    "type": "int",
                    "default": 50,
                    "inputBinding": {
                        "prefix": "--max-diff-ref"
                    },
                    "description": "Only report reads differing by at most this number of bp from the reference allele",
                    "id": "#lobSTR-tool.cwl/max-diff-ref"
                },
                {
                    "type": "int",
                    "default": 1000,
                    "inputBinding": {
                        "prefix": "--max-hits-quit-aln"
                    },
                    "description": "Stop alignment search after this many hits found. Use -1 for no limit.",
                    "id": "#lobSTR-tool.cwl/max-hits-quit-aln"
                },
                {
                    "type": "int",
                    "default": 1024,
                    "inputBinding": {
                        "prefix": "--min-read-length"
                    },
                    "description": "Don't process reads longer than this",
                    "id": "#lobSTR-tool.cwl/max-read-length"
                },
                {
                    "type": "int",
                    "default": 100,
                    "inputBinding": {
                        "prefix": "--maxflank"
                    },
                    "description": "Length to trim flanking regions to before aligning",
                    "id": "#lobSTR-tool.cwl/maxflank"
                },
                {
                    "type": "int",
                    "default": 30,
                    "inputBinding": {
                        "prefix": "--min-flank-allow-mismatch"
                    },
                    "description": "Don't allow mismatches if aligning flanking regions shorter than this",
                    "id": "#lobSTR-tool.cwl/min-flank-allow-mismatch"
                },
                {
                    "type": "int",
                    "default": 45,
                    "inputBinding": {
                        "prefix": "--min-read-length"
                    },
                    "description": "Don't process reads shorter than this",
                    "id": "#lobSTR-tool.cwl/min-read-length"
                },
                {
                    "type": "int",
                    "default": 8,
                    "inputBinding": {
                        "prefix": "--minflank"
                    },
                    "description": "Minimum length of flanking region to try to align",
                    "id": "#lobSTR-tool.cwl/minflank"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--mismatch"
                    },
                    "description": "allowed edit distance in either flanking region",
                    "id": "#lobSTR-tool.cwl/mismatch"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--multi"
                    },
                    "description": "Report reads mapping to multiple genomic locations",
                    "id": "#lobSTR-tool.cwl/multi"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--oldillumina"
                    },
                    "description": "specifies that base pair quality scores are reported in the old Phred\nformat (Illumina 1.3+, Illumina 1.5+) where quality scores are given as\nPhred + 64 rather than Phred + 33\n",
                    "id": "#lobSTR-tool.cwl/oldillumina"
                },
                {
                    "type": "string",
                    "description": "prefix for output files. will output prefix.aligned.bam and prefix.aligned.stats",
                    "inputBinding": {
                        "prefix": "--out"
                    },
                    "id": "#lobSTR-tool.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "description": "list of files containing the first end of paired end reads in fasta or fastq format",
                    "inputBinding": {
                        "prefix": "--p1",
                        "position": 2,
                        "itemSeparator": ","
                    },
                    "id": "#lobSTR-tool.cwl/p1"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "description": "list of files containing the second end of paired end reads in fasta or fastq format",
                    "inputBinding": {
                        "prefix": "--p2",
                        "position": 3,
                        "itemSeparator": ","
                    },
                    "id": "#lobSTR-tool.cwl/p2"
                },
                {
                    "type": "float",
                    "default": -1,
                    "inputBinding": {
                        "prefix": "-e"
                    },
                    "description": "fraction of missing alignments given 2% uniform base error rate. Ignored if --mismatch is set",
                    "id": "#lobSTR-tool.cwl/r"
                },
                {
                    "type": "File",
                    "description": "lobSTR's bwa reference files",
                    "inputBinding": {
                        "prefix": "--index-prefix",
                        "valueFrom": "$({\"path\": self.path.replace(/ref\\.fasta$/, \"\"), \"class\": \"File\"})\n"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".rbwt",
                        ".rpac",
                        ".rsa",
                        ".sa",
                        "$(self.path.replace(/ref$/, \"chromsizes.tab\"))",
                        "$(self.path.replace(/ref$/, \"mergedref.bed\"))",
                        "$(self.path)_map.tab"
                    ],
                    "id": "#lobSTR-tool.cwl/reference"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--rg-lib"
                    },
                    "description": "Use this in the read group LB tag",
                    "id": "#lobSTR-tool.cwl/rg-lib"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--rg-sample"
                    },
                    "description": "Use this in the read group SM tag",
                    "id": "#lobSTR-tool.cwl/rg-sample"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-u"
                    },
                    "description": "only report reads different by an integer number of copy numbers from the reference allele",
                    "id": "#lobSTR-tool.cwl/u"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs['output_prefix'] + '.aligned.bam')"
                    },
                    "id": "#lobSTR-tool.cwl/bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs['output_prefix'] + '.aligned.stats')"
                    },
                    "id": "#lobSTR-tool.cwl/bam_stats"
                }
            ],
            "baseCommand": [
                "lobSTR"
            ],
            "arguments": [
                "--verbose",
                "--noweb",
                {
                    "valueFrom": "${\n  var r = /.*(\\.fastq|\\.fq)(\\.gz)?$/i;\n  var m;\n  if (inputs['files']) {\n    m = r.exec(inputs.files[0].path);\n  } else {\n    m = r.exec(inputs.p1[0].path);\n  }\n  if (m) {\n    if (m[2]) {\n      return [\"--fastq\", \"--gzip\"];\n    } else {\n      return \"--fastq\";\n    }\n  } else {\n    return null;\n  }\n}\n"
                },
                {
                    "valueFrom": "${\n  if (inputs['files'] && (/.*\\.bam$/i).test(inputs['files'][0].path) && !inputs.bampair) {\n    return \"--bam\";\n  } else {\n    return null;\n  }\n}\n"
                }
            ],
            "id": "#lobSTR-tool.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "description": "File to read noise model parameters from (.stepmodel)",
                    "secondaryFiles": [
                        "^.stuttermodel"
                    ],
                    "id": "#main/noise_model"
                },
                {
                    "type": "string",
                    "description": "prefix for output files. will output prefix.aligned.bam and prefix.aligned.stats",
                    "id": "#main/output_prefix"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "description": "list of files containing the first end of paired end reads in fasta or fastq format",
                    "id": "#main/p1"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "description": "list of files containing the second end of paired end reads in fasta or fastq format",
                    "id": "#main/p2"
                },
                {
                    "type": "File",
                    "description": "lobSTR's bwa reference files",
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "description": "Use this in the read group LB tag",
                    "id": "#main/rg-lib"
                },
                {
                    "type": "string",
                    "description": "Use this in the read group SM tag",
                    "id": "#main/rg-sample"
                },
                {
                    "type": "File",
                    "description": "File containing statistics for each STR.",
                    "id": "#main/strinfo"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/samindex/bam_with_bai",
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/lobSTR/bam_stats",
                    "id": "#main/bam_stats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/allelotype/vcf",
                    "id": "#main/vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/allelotype/vcf_stats",
                    "id": "#main/vcf_stats"
                }
            ],
            "requirements": [
                {
                    "dockerPull": "rabix/lobstr",
                    "class": "DockerRequirement"
                }
            ],
            "steps": [
                {
                    "run": "#allelotype.cwl",
                    "in": [
                        {
                            "source": "#main/samindex/bam_with_bai",
                            "id": "#main/allelotype/bam"
                        },
                        {
                            "source": "#main/noise_model",
                            "id": "#main/allelotype/noise_model"
                        },
                        {
                            "source": "#main/output_prefix",
                            "id": "#main/allelotype/output_prefix"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/allelotype/reference"
                        },
                        {
                            "source": "#main/strinfo",
                            "id": "#main/allelotype/strinfo"
                        }
                    ],
                    "out": [
                        "#main/allelotype/vcf",
                        "#main/allelotype/vcf_stats"
                    ],
                    "id": "#main/allelotype"
                },
                {
                    "run": "#lobSTR-tool.cwl",
                    "in": [
                        {
                            "source": "#main/output_prefix",
                            "id": "#main/lobSTR/output_prefix"
                        },
                        {
                            "source": "#main/p1",
                            "id": "#main/lobSTR/p1"
                        },
                        {
                            "source": "#main/p2",
                            "id": "#main/lobSTR/p2"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/lobSTR/reference"
                        },
                        {
                            "source": "#main/rg-lib",
                            "id": "#main/lobSTR/rg-lib"
                        },
                        {
                            "source": "#main/rg-sample",
                            "id": "#main/lobSTR/rg-sample"
                        }
                    ],
                    "out": [
                        "#main/lobSTR/bam",
                        "#main/lobSTR/bam_stats"
                    ],
                    "id": "#main/lobSTR"
                },
                {
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#main/samsort/output_file",
                            "id": "#main/samindex/input"
                        }
                    ],
                    "out": [
                        "#main/samindex/bam_with_bai"
                    ],
                    "id": "#main/samindex"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "id": "#main/samsort/input",
                            "source": "#main/lobSTR/bam"
                        },
                        {
                            "id": "#main/samsort/output_name",
                            "default": "aligned.sorted.bam"
                        }
                    ],
                    "out": [
                        "#main/samsort/output_file"
                    ],
                    "id": "#main/samsort"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "description": "Invoke 'samtools index' to create a 'BAI' index (samtools 1.19)",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.input)"
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "description": "Input bam file.",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)"
                    },
                    "id": "#samtools-index.cwl/input"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input.basename)"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#samtools-index.cwl/bam_with_bai"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "id": "#samtools-index.cwl"
        },
        {
            "class": "CommandLineTool",
            "description": "Invoke 'samtools sort' (samtools 1.19)",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "description": "Set the desired compression level for the final output file, ranging from\n0 (uncompressed) or 1 (fastest but minimal compression) to 9 (best\ncompression but slowest to write), similarly to gzip(1)'s compression\nlevel setting.\n\nIf -l is not used, the default compression level will apply.\n",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#samtools-sort.cwl/compression_level"
                },
                {
                    "type": "File",
                    "description": "Input bam file.",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools-sort.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "description": "Approximately the maximum required memory per thread, specified  in\nbytes.\n",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#samtools-sort.cwl/memory"
                },
                {
                    "type": "string",
                    "description": "Desired output filename.",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#samtools-sort.cwl/output_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "description": "Sort by read names (i.e., the QNAME field) rather than by chromosomal coordinates.",
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "id": "#samtools-sort.cwl/sort_by_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs['output_name'])"
                    },
                    "id": "#samtools-sort.cwl/output_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "arguments": [
                "-f"
            ],
            "id": "#samtools-sort.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
